import React from "react";
import { NavBar, Space, Toast } from 'antd-mobile'
import { SearchOutline, MoreOutline, CloseOutline } from 'antd-mobile-icons'
import './index.css'
import axios from "axios";
import { getCurrentCity } from "../../utils";
import { List, AutoSizer } from "react-virtualized";
import WidthUseNavigate from "../WidthUseNavigate";
import NavHeader from "../../components/NavHeader";
import styles from './index.module.css'
console.log(styles)
// list:[{},{}]
const formatCityIndex = (letter) => {
    switch (letter) {
        case '#':
            return '当前城市'
        case 'hot':
            return '热门城市'
        default:
            return letter.toUpperCase()
    }
}
const formatCityData = (list) => {
    // {{'a':{},'b':{}}}
    const cityList = {}
    // 遍历
    list.forEach(element => {
        //获取短名称的第一个字母
        const first = element.short.substr(0, 1)
        //判断cityList中是否包含
        if (cityList[first]) {
            cityList[first].push(element)
        } else {
            cityList[first] = [element]
        }
    });
    const cityIndex = Object.keys(cityList).sort()
    return {
        cityList,
        cityIndex
    }
}

const HOUSE_CITY= ['北京','上海','广州','深圳']
// const right = (
//     <div style={{ fontSize: 24 }}>
//         <Space style={{ '--gap': '16px' }}>
//             <SearchOutline />
//             <MoreOutline />
//         </Space>
//     </div>
// )

const back = () => { }
// Toast.show({
//   content: '点击了返回区域',
//   duration: 1000,
// })
// const list =
//     //  [
//     //     'Brian Vaughn',
//     //     // And so on...
//     // ];
//     Array(100).fill('Brian Vaughn')
// function rowRenderer({
//     key, // Unique key within array of rows
//     index, // Index of row within collection
//     isScrolling, // The List is currently being scrolled
//     isVisible, // This row is visible within the List (eg it is not an overscanned row)
//     style, // Style object to be applied to row (to position it)
// }) {
//     return (
//         <div key={key} style={style}>
//             {list[index]}
//         </div>
//     );
// }
class CityListInner extends React.Component {

    constructor(props){
        super(props)
        this.state = {
            cityList: {},
            cityIndex: [],
            activeIndex: 0
        }
        this.cityListComponent = React.createRef()
    }
    async componentDidMount() {
        await this.getCityList()
        //提前计算list高度
        this.cityListComponent.current.measureAllRows()
    }
    async getCityList() {
        const res = await axios.get('http://localhost:8080/area/city?level=1')
        const { cityList, cityIndex } = formatCityData(res.data.body)

        // 热门城市数据
        const hotRes = await axios.get('http://localhost:8080/area/hot')
        cityList['hot'] = hotRes.data.body
        // 放在第一位
        cityIndex.unshift('hot')

        const curCity = await getCurrentCity();
        cityList['#'] = [curCity]
        cityIndex.unshift('#')

        this.setState({
            cityList,
            cityIndex
        })
        // this.setState(()=>{
        //     return {
        //         cityList:cityList,
        //         cityIndex:cityIndex
        //     }
        // })
    }

    rowRenderer = ({
        key, // Unique key within array of rows
        index, // Index of row within collection
        isScrolling, // The List is currently being scrolled
        isVisible, // This row is visible within the List (eg it is not an overscanned row)
        style, // Style object to be applied to row (to position it)
    }) => {
        const cityIndex = this.state.cityIndex
        const letter = cityIndex[index]
        return (
            <div key={key} style={style} className="city">
                <div className="title">{formatCityIndex(letter)}</div>
                {
                    this.state.cityList[letter].map(item => (
                        <div className="name" key={item.value} onClick={()=>this.changeCity(item)}>{item.label}</div>
                    ))
                }
            </div>
        );
    }
    getRowHeight = ({ index }) => {
        return 36 + this.state.cityList[this.state.cityIndex[index]].length * 20
    }

    renderCityIndex() {
        const { cityIndex, activeIndex } = this.state
        return cityIndex.map((item, index) => (
            <li className="city-index-item" key={item} onClick={()=>{this.cityListComponent.current.scrollToRow(index)}}>
                <span className={activeIndex === index ? "index-active" : ''}>{item === 'hot' ? '热' : item.toUpperCase()}</span>
            </li>
        ))
    }
    // 用户获取list组件渲染行数据
    onRowsRendered=({startIndex})=>{
        if(this.state.activeIndex!=startIndex){
            this.setState({
                activeIndex:startIndex
            })
        } 
    }
    changeCity({label,value}){
        if(HOUSE_CITY.indexOf(label)>-1){
            localStorage.setItem('local_city',JSON.stringify({label,value}))
            // 返回上一个页面
            this.props.to(-1)
        }else{
            Toast.show('该城市暂无房源数据') 
        }
    }

    render() {
        return <div className="citylist"><NavHeader>城市选择</NavHeader>
            <AutoSizer>
                {({ width, height }) => (
                    <List
                        width={width}
                        height={height}
                        ref={this.cityListComponent}
                        rowCount={this.state.cityIndex.length}
                        rowHeight={this.getRowHeight}
                        rowRenderer={this.rowRenderer}
                        onRowsRendered={this.onRowsRendered}
                        scrollToAlignment="start"                    />
                )}
            </AutoSizer>
            <ul className="city-index">{this.renderCityIndex()}</ul>
        </div>
    }
}

// 使用高阶组件包裹当前类组件
const CityList = WidthUseNavigate(CityListInner);
export default CityList